@@ -1,19 +1,9 @@
+/* SPDX-License-Identifier: BSD-2-Clause */
+
 /*
  * The SIP module interface.
  *
- * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
- *
- * This file is part of SIP.
- *
- * This copy of SIP is licensed for use under the terms of the SIP License
- * Agreement.  See the file LICENSE for more details.
- *
- * This copy of SIP may also used under the terms of the GNU General Public
- * License v2 or v3 as published by the Free Software Foundation which can be
- * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
- *
- * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * Copyright (c) 2024 Phil Thompson <phil@riverbankcomputing.com>
  */
 
 
@@ -24,8 +14,8 @@
 #include <Python.h>
 
 /* Sanity check on the Python version. */
-#if PY_VERSION_HEX < 0x03070000
-#error "This version of wx.siplib requires Python v3.7 or later"
+#if PY_VERSION_HEX < 0x03090000
+#error "This version of wx.siplib requires Python v3.9 or later"
 #endif
 
 
@@ -45,13 +35,31 @@ extern "C" {
 
 /* The version of the ABI. */
 #define SIP_ABI_MAJOR_VERSION       12
-#define SIP_ABI_MINOR_VERSION       12
-#define SIP_MODULE_PATCH_VERSION    2
+#define SIP_ABI_MINOR_VERSION       16
+#define SIP_MODULE_PATCH_VERSION    1
 
 
 /*
  * The change history of the ABI.
  *
+ * v12.16
+ *  - Python v3.9 or later is required.
+ *  - Added a new implementation of sipDeprecated() that takes an optional
+ *    supplementary message.
+ *
+ * v12.15
+ *  - Added the 'I' conversion character to the argument and result parsers.
+ *
+ * v12.14
+ *  - Added support for Python v3.13.
+ *  - Python v3.8 or later is required.
+ *  - C99 support is assumed.
+ *
+ * v12.13
+ *  - Added support for Python v3.12.
+ *  - Added sipPyTypeDictRef().
+ *  - Deprecated sipPyTypeDict().
+ *
  * v12.12
  *  - Added the '#' conversion character to the argument parsers.
  *
@@ -73,8 +81,8 @@ extern "C" {
 
 
 /* The version of the code generator. */
-#define SIP_VERSION                 0x6070b
-#define SIP_VERSION_STR             "6.7.11"
+#define SIP_VERSION                 0x60901
+#define SIP_VERSION_STR             "6.9.1"
 
 /* These are all dependent on the user-specified name of the sip module. */
 #define _SIP_MODULE_FQ_NAME         "wx.siplib"
@@ -1668,6 +1676,17 @@ typedef struct _sipAPIDef {
     PyObject *(*api_is_py_method_12_8)(sip_gilstate_t *gil, char *pymc,
             sipSimpleWrapper **sipSelfp, const char *cname, const char *mname);
     sipExceptionHandler (*api_next_exception_handler)(void **statep);
+
+    /*
+     * The following are part of the public API.
+     */
+    PyObject *(*api_py_type_dict_ref)(PyTypeObject *);
+
+    /*
+     * The following are part of the private API.
+     */
+    int (*api_deprecated_12_16)(const char *classname, const char *method, const char *message);
+
 } sipAPIDef;
 
 const sipAPIDef *sip_init_library(PyObject *mod_dict);
